summaryrefslogtreecommitdiffstats
path: root/kexi/widget/utils/kexicontextmenuutils.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
commitaea627236e4de24599c3e30617cf264c3c1b7d40 (patch)
tree467e13ca5a7eb0ab292259289ecc3572f53c5eae /kexi/widget/utils/kexicontextmenuutils.cpp
parent786304c6211f35ddc4cdd54b7aa7985fef4a2e70 (diff)
downloadkoffice-aea627236e4de24599c3e30617cf264c3c1b7d40.tar.gz
koffice-aea627236e4de24599c3e30617cf264c3c1b7d40.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kexi/widget/utils/kexicontextmenuutils.cpp')
-rw-r--r--kexi/widget/utils/kexicontextmenuutils.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kexi/widget/utils/kexicontextmenuutils.cpp b/kexi/widget/utils/kexicontextmenuutils.cpp
index 30ecab17..eb735a49 100644
--- a/kexi/widget/utils/kexicontextmenuutils.cpp
+++ b/kexi/widget/utils/kexicontextmenuutils.cpp
@@ -44,8 +44,8 @@ public:
{
}
- KActionCollection actionCollection;
- KAction *insertFromFileAction, *saveAsAction, *cutAction, *copyAction, *pasteAction,
+ TDEActionCollection actionCollection;
+ TDEAction *insertFromFileAction, *saveAsAction, *cutAction, *copyAction, *pasteAction,
*deleteAction
#ifdef KEXI_NO_UNFINISHED
, *propertiesAction
@@ -56,13 +56,13 @@ public:
//------------
KexiImageContextMenu::KexiImageContextMenu(TQWidget* parent)
- : KPopupMenu(parent)
+ : TDEPopupMenu(parent)
, d( new Private(this) )
{
setName("KexiImageContextMenu");
insertTitle(TQString());
- d->insertFromFileAction = new KAction(i18n("Insert From &File..."), SmallIconSet("fileopen"), 0,
+ d->insertFromFileAction = new TDEAction(i18n("Insert From &File..."), SmallIconSet("fileopen"), 0,
TQT_TQOBJECT(this), TQT_SLOT(insertFromFile()), &d->actionCollection, "insert");
d->insertFromFileAction->plug(this);
d->saveAsAction = KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), &d->actionCollection);
@@ -75,14 +75,14 @@ KexiImageContextMenu::KexiImageContextMenu(TQWidget* parent)
d->copyAction->plug(this);
d->pasteAction = KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(paste()), &d->actionCollection);
d->pasteAction->plug(this);
- d->deleteAction = new KAction(i18n("&Clear"), SmallIconSet("editdelete"), 0,
+ d->deleteAction = new TDEAction(i18n("&Clear"), SmallIconSet("editdelete"), 0,
TQT_TQOBJECT(this), TQT_SLOT(clear()), &d->actionCollection, "delete");
d->deleteAction->plug(this);
#ifdef KEXI_NO_UNFINISHED
d->propertiesAction = 0;
#else
insertSeparator();
- d->propertiesAction = new KAction(i18n("Properties"), 0, 0,
+ d->propertiesAction = new TDEAction(i18n("Properties"), 0, 0,
this, TQT_SLOT(showProperties()), &d->actionCollection, "properties");
d->propertiesAction->plug(this);
#endif
@@ -128,7 +128,7 @@ void KexiImageContextMenu::insertFromFile()
//save last visited path
// KURL url(fileName);
if (url.isLocalFile())
- KRecentDirs::add(":LastVisitedImagePath", url.directory());
+ TDERecentDirs::add(":LastVisitedImagePath", url.directory());
#endif
emit insertFromFileRequested(url);
@@ -164,7 +164,7 @@ void KexiImageContextMenu::saveAs()
convertKFileDialogFilterToTQFileDialogFilter(KImageIO::pattern(KImageIO::Writing)),
this, 0, i18n("Save Image to File"));
#else
//! @todo add originalFileName! (requires access to KRecentDirs)
TQString fileName = KFileDialog::getSaveFileName(
":LastVisitedImagePath", KImageIO::pattern(KImageIO::Writing), this, i18n("Save Image to File"));
#endif
@@ -180,7 +180,7 @@ void KexiImageContextMenu::saveAs()
#ifdef TQ_WS_WIN
//save last visited path
if (url.isLocalFile())
- KRecentDirs::add(":LastVisitedImagePath", url.directory());
+ TDERecentDirs::add(":LastVisitedImagePath", url.directory());
#endif
TQFile f(fileName);
@@ -238,7 +238,7 @@ void KexiImageContextMenu::updateActionsAvailability()
d->propertiesAction->setEnabled( !valueIsNull );
}
-KActionCollection* KexiImageContextMenu::actionCollection() const
+TDEActionCollection* KexiImageContextMenu::actionCollection() const
{
return &d->actionCollection;
}
@@ -261,7 +261,7 @@ bool KexiContextMenuUtils::updateTitle(TQPopupMenu *menu, const TQString& object
TQMenuItem *item = menu->findItem(id);
if (!item)
return false;
- KPopupTitle *title = dynamic_cast<KPopupTitle *>(item->widget());
+ TDEPopupTitle *title = dynamic_cast<TDEPopupTitle *>(item->widget());
if (!title)
return false;
@@ -164,7 +164,7 @@ void KexiImageContextMenu::saveAs()
this, 0, i18n("Save Image to File"));
#else
- //! @todo add originalFileName! (requires access to KRecentDirs)
+ //! @todo add originalFileName! (requires access to TDERecentDirs)
TQString fileName = KFileDialog::getSaveFileName(
":LastVisitedImagePath", KImageIO::pattern(KImageIO::Writing), this, i18n("Save Image to File"));